@@ -137,6 +137,8 @@ def resort_quad_points(src_pts):
            [  0,  50]])
     """
     pts = copy.copy(src_pts)
+    if isinstance(pts, np.ndarray):
+        pts = pts.tolist()
     if pts[0][1] > pts[2][1]:
         pts[0], pts[2] = pts[2], pts[0]
     if pts[1][1] > pts[3][1]:
@@ -516,8 +518,8 @@ def bound_scale(bound, scale):
     :param scale: 比例，例如0.5，就是缩放一半
     """
     x1, y1, x2, y2 = bound
-    x0 = (x2 - x1) / 2
-    y0 = (y2 - y1) / 2
+    x0 = (x2 + x1) / 2
+    y0 = (y2 + y1) / 2
     r = 1 - scale ** 0.5
 
     x1 += r * abs(x0 - x1)
